#!/usr/bin/env bash
IFS=$'\n'
set -o xtrace -o errexit -o errtrace -o nounset -o pipefail +o history
umask 0077

WORK_DIR="${HOME}"
SUB_DIR="talos"
SNAPSHOT_ARCHIVE="talos_day$(date +%d).tgz"

mkdir -p "${WORK_DIR}/${SUB_DIR}"
cd "${WORK_DIR}/${SUB_DIR}"
talosctl etcd snapshot "db.snapshot" &>"db.snapshot.log"
talosctl get members --output yaml >"members.yaml"
while read -r NODE_IP; do
  talosctl get machineconfig -o yaml -n "${NODE_IP}" >"machineconfig.${NODE_IP}.yaml"
done < <(talosctl get members --output json | jq -r '.spec.addresses[] | select(test("^[0-9\\.]+$"))')

cd "${WORK_DIR}"
tar -cpzf "${SNAPSHOT_ARCHIVE}" "${SUB_DIR}"
rm  -rf  "${WORK_DIR}/${SUB_DIR}"

ls -lah "${SNAPSHOT_ARCHIVE}"

echo "Backup completed - $(date)"
